@@ -39,14 +39,7 @@ class RandomRequestUaMiddleware(object):
     随机请求头中间件
     """
     def get_random_ua_by_weight(self) -> str:
-        """
-        根据权重来获取随机请求头 ua 信息
-        Args:
-            None
-
-        Returns:
-            curr_ua: 当前返回的随机请求 ua 信息
-        """
+        """根据权重来获取随机请求头 ua 信息"""
         # 带权重的 ua 列表，将比较常用的 ua 标识的权重设置高一点。这里是根据 fake_useragent 库中的打印信息来规划权重的。
         ua_arr = [
             {"explorer_type": "opera", "weight": 16},
@@ -104,7 +97,7 @@ class DynamicProxyDownloaderMiddleware(object):
         return s
 
     def process_request(self, request, spider):
-        # TODO: 根据权重来随机获取一个账号DYNAMIC_PROXY_CONFIG
+        # TODO: 根据权重来随机获取一个账号 DYNAMIC_PROXY_CONFIG
         # account = ReuseOperation.random_weight(self.account_arr)
         if request.url.startswith("https://"):
             request.meta['proxy'] = f"https://{self.username}:{self.password}@{self.proxy_url}/"
@@ -154,14 +147,7 @@ class ExclusiveProxyDownloaderMiddleware(object):
         return s
 
     def get_proxy_ip(self):
-        """
-        获取独享代理接口的索引为 proxy_index 的代理信息
-        Args:
-            None
-
-        Returns:
-            proxy: 独享代理中索引为 proxy_index 的代理
-        """
+        """获取独享代理接口的索引为 proxy_index 的代理信息"""
         try:
             r = requests.get(self.proxy_url)
             proxy_list = r.json().get("data").get("proxy_list")
@@ -307,8 +293,8 @@ class SiMiProxyDownloaderMiddleware(RetryMiddleware):
                 self.simidaili_config["orderid"], self.simidaili_config["signature"],
                 current_ip)
             is_exists = requests.get(url).json()
-            if (not is_exists["data"][current_ip]):
-                if (current_ip in self.proxy_list):
+            if not is_exists["data"][current_ip]:
+                if current_ip in self.proxy_list:
                     spider.logger.info("更新ip")
                     # 找到相应索引，并删除相应时间统计数组、ip列表以及请求次数统计数组相应索引上的值
                     current_ip_index = self.proxy_list.index(current_ip)
@@ -324,7 +310,7 @@ class SiMiProxyDownloaderMiddleware(RetryMiddleware):
                             self.reqnum_count = np.append(self.reqnum_count, 0)
                             current_ip = new_ip
                             self.reqnum_count[-1] += 1
-                    elif (len(self.proxy_list) < self.proxypool_size):
+                    elif len(self.proxy_list) < self.proxypool_size:
                         new_ip = self.get_proxy_ip(1)[0]
                         self.proxy_list.append(new_ip)
                         self.time_count = np.append(self.time_count, 0.5)
